@@ -170,8 +170,8 @@ PolySTest_unpaired <- function(fulldata, allComps,
         
         lratios <- cbind(
             lratios,
-            rowMeans(Data[, Reps == RRCateg[1, vs], drop=FALSE], na.rm = TRUE) -
-                rowMeans(Data[, Reps == RRCateg[2, vs], drop=FALSE], 
+            rowMeans(Data[, Reps == RRCateg[2, vs], drop=FALSE], na.rm = TRUE) -
+                rowMeans(Data[, Reps == RRCateg[1, vs], drop=FALSE], 
                          na.rm = TRUE)
         )
         setTxtProgressBar(pb, vs)
@@ -379,7 +379,7 @@ rp_unpaired <- function(tData, trefData) {
     })
     stopCluster(cl)
 
-     save(RPparOut, tData, trefData, file="/tmp/t.csv")
+#save(RPparOut, tData, trefData, file="/tmp/t.csv")
      for (p in seq_len(NumRPPairs)) {
          names(RPparOut[[p]]) <- rownames(tData)
          tpRPvalues[names(RPparOut[[p]]), p] <- RPparOut[[p]]
